@@ -6,10 +6,12 @@ Check these declarations against the C/Fortran source code.
 */
 
 /* .C calls */
+extern void jointlevel_onesided(void *, void *, void *, void *, void *, void *);
 extern void jointlevel_twosided(void *, void *, void *, void *);
 extern void jointlevel_twosided_ell_speedup(void *, void *, void *, void *);
 
 static const R_CMethodDef CEntries[] = {
+  {"jointlevel_onesided",             (DL_FUNC) &jointlevel_onesided,             6},
   {"jointlevel_twosided",             (DL_FUNC) &jointlevel_twosided,             4},
   {"jointlevel_twosided_ell_speedup", (DL_FUNC) &jointlevel_twosided_ell_speedup, 4},
   {NULL, NULL, 0}
